==> mingw-w64-tfel-4.2.0-2.src.tar.zst: tfel-TFEL-4.2.0/docs/web/publications.md <==
---
title: Publications
author: Thomas Helfer
date: 1/10/2020
lang: en-EN
link-citations: true
colorlinks: true
figPrefixTemplate: "$$i$$"
tblPrefixTemplate: "$$i$$"
secPrefixTemplate: "$$i$$"
eqnPrefixTemplate: "($$i$$)"
---

---
nocite: |
    @fokam_implementation_2023
    @bacquaert_standard_2023
    @rapanakis_three-dimensional_2023
    @lewandowski_multifield_2023
    @socie_fully_2023
    @abbas_3d_2023
    @riparbelli_hygromechanical_2023
    @riparbelli_coupling_2023
    @senac_yield_2023
    @agius_experimental_2023
    @madec_plastic_2023
    @ziegelwanger_pcba_2023
    @tsekpuia_microstructure-based_2023
    @riparbelli_hygromechanical_2023
    @zhang_modeling_2023
    @siedel_approche_2023
    @soleilhet_numerical_2023
    @mollens_development_2022
    @draup_development_2022
    @fokam_implantation_2022
    @gelebart_simple_2022
    @jamond_manta_2022
    @fandeur_approche_2022
    @siedel_schema_2022
    @bacquaert_formulation_2022
    @li_influence_2022
    @seidlhofer_hygro-coupled_2022
    @kafle_numerical_2022
    @elabdi:tel-03247723
    @senac2021
    @marano_fft-based_2021
    @singh_irradiation_2021
    @guo_nspfem2d_2021
    @parise_etude_2021
    @li_large-deformation_2021
    @reymond_thermo-mechanical_2021
    @liang_micromechanical_2021
    @gelebart_grain_2021
    @seidlhofer_compressible_2021
    @hure_yield_2021
    @shokeir_extension_2021
    @jacquet_elasto-visco-plastic_2020
    @dambrosi_homogenization_2020
    @dambrosi_detection_2020
    @parisio_model_2020
    @garcia_effect_2020
    @deng_slope_2020
    @masson_modified_2020
    @helfer_assisted_2020
    @bleyer_small-strain_2020
    @bleyer_multiphase_2020
    @bleyer_transient_2020
    @bleyer_monolithic_2020
    @bleyer_stationnary_2020
    @bleyer_stationnary_2020b
    @bleyer_phase-field_2020
    @bleyer_overview_2020
    @bleyer_finite-strain_2020
    @helfer_extending_2020
    @helfer_using_2020
    @helfer_mfrontgenericinterfacesupport_2020
    @lu_efficient_2020
    @marano_non-linear_2020
    @boustani_extending_2020
    @socie_modelisation_2019
    @barrioz_effect_2019
    @draup_development_2019
    @manso_settlement_2019
    @singh_brittle_2019
    @tuset_implementation_2019
    @szmytka_recent_2019
    @forre_comparison_2019
    @helfer_pdf_2019
    @helfer_mgis_2019
    @bleyer_elasto-plastic_2019
    @marano_intragranular_2019
    @perales_xper_2019    
    @helfer_new_2019
    @dorfler_numerical_2019
    @bernachy-barbe_effect_2019
    @bejaoui_description_2019
	@lemerle_mesure_2018
    @bouhjiti_analyse_2018
    @hure_coalescence_2018
    @barrioz_void_shape_2018
	@portelette_crystal_2018
	@barrioz_void_2018
	@shi_experimental_2018
	@torelli_confinement-dependent_2018
	@guenot-delahaie_simulation_2018
	@abbas_hybrid_2018_2
	@abbas_hybrid_2018
	@carre_implementation_2017
	@michel_new_2017
	@bary_analytical_2017
	@gelebart_fft_2017
	@chetra_modecomportement_2017
	@helfer_phase_field_2017
	@helfer_mfront_2017
	@farsi_full_2017
	@portillo_muesli_2017
	@seck_three_2016
	@torelli_multiaxial_2016
	@michel_3d_2016
	@bary_thermoviscoelastic_2016
	@asali_modelisation_2016
	@asali_numerical_2016
	@hure_intergranular_2016
	@saouma16:_effec
	@honorio_multiscale_2016
	@blanc_characterization_2015
	@helfer_licos_2015
	@helfer_implantation_2015
	@helfer_extension_2015
	@helfer_introducing_2015
	@ramiere_iterative_2015
	@salvo_experimental_2015
	@salvo_experimental_2015-1
	@hure_warm_2015
	@sercombe_2d_2015
	@bary_numerical_2015
	@petry_advanced_2015
	@soulacroix_aging_2014
	@helfer_fuel_2009
...

==> mingw-w64-tfel-5.0.0-1.src.tar.zst: tfel-TFEL-5.0.0/docs/web/publications.md <==
---
title: Publications
author: Thomas Helfer
date: 1/10/2020
lang: en-EN
link-citations: true
colorlinks: true
figPrefixTemplate: "$$i$$"
tblPrefixTemplate: "$$i$$"
secPrefixTemplate: "$$i$$"
eqnPrefixTemplate: "($$i$$)"
---

---
nocite: |
    @rapanakis_cross-anisotropic_2024
    @nagel_hierarchical_2024
    @machado_alves_da_fonseca_viscoplastic_2024
    @ribeiro_nogueira_eikonal_2024
    @bary_mesoscale_2024
    @barani_assessing_2024
    @bernaud_pleiades_2024
    @gril_combining_2024
    @balaguer_enhanced_2024
    @introini_alcyone_2024
    @abou_chakra_micromechanical_2024
    @josien_merope_2024
    @chen_anisotropic_2024
    @mohanan_intergranular_2024
    @scherer_tensile_2024
    @vedrine_role_2024
    @senac_yield_2024
    @helfer_new_2024
    @jamond_manta_2024
    @valmalle_dic_2024
    @lorenzo_exploring_2024
    @simo_novel_2024
    @singh_irradiation_2024
    @gicquel_polycrystalline_2023
    @gicquel_developpement_2023
    @loiseau_formulation_2023
    @thuillet_modelisation_2023
    @wang_modelling_2023
    @fokam_implementation_2023
    @bacquaert_standard_2023
    @rapanakis_three-dimensional_2023
    @lewandowski_multifield_2023
    @socie_fully_2023
    @abbas_3d_2023
    @riparbelli_hygromechanical_2023
    @riparbelli_coupling_2023
    @senac_yield_2023
    @agius_experimental_2023
    @madec_plastic_2023
    @ziegelwanger_pcba_2023
    @tsekpuia_microstructure-based_2023
    @riparbelli_hygromechanical_2023
    @zhang_modeling_2023
    @siedel_approche_2023
    @soleilhet_numerical_2023
    @beccantini_europlexus_2022
    @helfer_mfem-mgis-mfront_2022
    @onimus_polycrystalline_2022
    @mollens_development_2022
    @draup_development_2022
    @fokam_implantation_2022
    @gelebart_simple_2022
    @jamond_manta_2022
    @fandeur_approche_2022
    @siedel_schema_2022
    @bacquaert_formulation_2022
    @li_influence_2022
    @seidlhofer_hygro-coupled_2022
    @kafle_numerical_2022
    @elabdi:tel-03247723
    @senac2021
    @marano_fft-based_2021
    @singh_irradiation_2021
    @guo_nspfem2d_2021
    @parise_etude_2021
    @li_large-deformation_2021
    @reymond_thermo-mechanical_2021
    @liang_micromechanical_2021
    @gelebart_grain_2021
    @seidlhofer_compressible_2021
    @hure_yield_2021
    @shokeir_extension_2021
    @jacquet_elasto-visco-plastic_2020
    @dambrosi_homogenization_2020
    @dambrosi_detection_2020
    @parisio_model_2020
    @garcia_effect_2020
    @deng_slope_2020
    @masson_modified_2020
    @helfer_assisted_2020
    @bleyer_small-strain_2020
    @bleyer_multiphase_2020
    @bleyer_transient_2020
    @bleyer_monolithic_2020
    @bleyer_stationnary_2020
    @bleyer_stationnary_2020b
    @bleyer_phase-field_2020
    @bleyer_overview_2020
    @bleyer_finite-strain_2020
    @helfer_extending_2020
    @helfer_using_2020
    @helfer_mfrontgenericinterfacesupport_2020
    @lu_efficient_2020
    @marano_non-linear_2020
    @boustani_extending_2020
    @socie_modelisation_2019
    @barrioz_effect_2019
    @draup_development_2019
    @manso_settlement_2019
    @singh_brittle_2019
    @tuset_implementation_2019
    @szmytka_recent_2019
    @forre_comparison_2019
    @helfer_pdf_2019
    @helfer_mgis_2019
    @bleyer_elasto-plastic_2019
    @marano_intragranular_2019
    @perales_xper_2019    
    @helfer_new_2019
    @dorfler_numerical_2019
    @bernachy-barbe_effect_2019
    @bejaoui_description_2019
	@lemerle_mesure_2018
    @bouhjiti_analyse_2018
    @hure_coalescence_2018
    @barrioz_void_shape_2018
	@portelette_crystal_2018
	@barrioz_void_2018
	@shi_experimental_2018
	@torelli_confinement-dependent_2018
	@guenot-delahaie_simulation_2018
	@abbas_hybrid_2018_2
	@abbas_hybrid_2018
	@carre_implementation_2017
	@michel_new_2017
	@bary_analytical_2017
	@gelebart_fft_2017
	@chetra_modecomportement_2017
	@helfer_phase_field_2017
	@helfer_mfront_2017
	@farsi_full_2017
	@portillo_muesli_2017
	@seck_three_2016
	@torelli_multiaxial_2016
	@michel_3d_2016
	@bary_thermoviscoelastic_2016
	@asali_modelisation_2016
	@asali_numerical_2016
	@hure_intergranular_2016
	@saouma16:_effec
	@honorio_multiscale_2016
	@blanc_characterization_2015
	@helfer_licos_2015
	@helfer_implantation_2015
	@helfer_extension_2015
	@helfer_introducing_2015
	@ramiere_iterative_2015
	@salvo_experimental_2015
	@salvo_experimental_2015-1
	@hure_warm_2015
	@sercombe_2d_2015
	@bary_numerical_2015
	@petry_advanced_2015
	@soulacroix_aging_2014
	@helfer_fuel_2009
...
